@@ -1,4 +1,5 @@
 from gateways.apis.api_base_class import ApiBase
+from gateways.common.cs18_api_requests import NewUserSurveyRequest
 
 
 class ApiAccount(ApiBase):
@@ -11,7 +12,7 @@ class ApiAccount(ApiBase):
     def account_login(self, account: str):
         return self.build_route(f"accounts/{account}/login")
 
-    def account_details(self, account: str):
+    def get_account_extra_details(self, account: str):
         return self.build_route(f"accounts/{account}/details")
 
     def forgot_password(self):
@@ -53,3 +54,6 @@ class ApiAccount(ApiBase):
 
     def set_account_extra_details(self, account_name: str) -> str:
         return self.build_route(f"accounts/{account_name}/details")
+
+    def submit_new_user_survey(self) -> str:
+        return self.build_route(f"accounts/roles_and_technologies")
