@@ -22,9 +22,13 @@ class ApiSpaces(ApiBase):
         """Astronauts"""
         return self.build_route("spaces/{space_name}/users".format(**locals()))
 
-    def space_repositories(self, space_name: str, repository_type: str = None):
+    def space_repositories(self, space_name: str, repository_type: str = None, deployment_type: str = None):
         if repository_type is None:
-            return self.build_route("spaces/{space_name}/repositories".format(**locals()))
+
+            if deployment_type is None:
+                return self.build_route("spaces/{space_name}/repositories".format(**locals()))
+            return self.build_route("spaces/{space_name}/repositories?type={deployment_type}".format(**locals()))
+
         if repository_type == 'bitbucket':
             return self.space_bitbucket_repositories(space_name)
 
@@ -90,3 +94,24 @@ class ApiSpaces(ApiBase):
     def repository_relationship(self, space_name: str, deployment_type: str):
         return self.build_route(f"spaces/{space_name}/repository_relationships/{deployment_type}")
 
+    def custom_space_tags(self, space_name: str):
+        return self.build_route(f"spaces/{space_name}/settings/tags")
+
+    def custom_space_tag(self, space_name: str, name: str):
+        return self.build_route(f"spaces/{space_name}/settings/tags/{name}")
+
+    def custom_blueprint_tags(self, space_name: str, blueprint_name: str, deployment_type: str):
+        return self.build_route(f"spaces/{space_name}/blueprints/{blueprint_name}/settings/tags?type={deployment_type}")
+
+    def custom_blueprint_tag(self, space_name: str, blueprint_name: str, name: str, deployment_type: str):
+        return self.build_route(f"spaces/{space_name}/blueprints/{blueprint_name}/settings/tags/{name}?type={deployment_type}")
+
+    def available_space_terraform_modules(self, space_name: str) -> str:
+        return self.build_route(f"spaces/{space_name}/tfmodules/available")
+
+    def attached_space_terraform_modules(self, space_name: str) -> str:
+        return self.build_route(f"spaces/{space_name}/tfmodules/attached")
+
+    def attached_space_terraform_module(self, space_name: str, module_alias: str) -> str:
+        return self.build_route(f"spaces/{space_name}/tfmodules/attached/{module_alias}")
+      
\ No newline at end of file
