@@ -1,6 +1,6 @@
 import json
 from datetime import datetime
-from typing import List, Optional
+from typing import List, Optional, Dict
 from urllib.parse import quote
 
 import time
@@ -538,7 +538,8 @@ class Colony:
             for item in json_result
         ]
 
-    def start_production(self, blueprint_name: str, artifacts: dict = None, inputs=None, compute_availability=None):
+    def start_production(self, blueprint_name: str, artifacts: dict = None, inputs=None, compute_availability=None,
+                         runtime_tags: Dict[str, str] = None):
         url = self._api_root.production.productions()
         response = self.session.post(
             url=url,
@@ -547,6 +548,7 @@ class Colony:
                 "artifacts": artifacts if artifacts else {},
                 "inputs": inputs if inputs else {},
                 "compute_availability": compute_availability,
+                "tags": runtime_tags if runtime_tags else {}
             },
         )
         GatewayUtils.handle_response(response=response, return_codes=[202])
@@ -557,12 +559,14 @@ class Colony:
                                production_id: str,
                                artifacts: dict = None,
                                inputs=None,
-                               compute_availability: str = None):
+                               compute_availability: str = None,
+                               runtime_tags: Dict[str, str] = None):
         url = self._api_root.production.green_by_id(production_id=production_id)
         response = self.session.post(url=url, json={
             "artifacts": artifacts if artifacts else {},
             "inputs": inputs if inputs else {},
-            "compute_availability": compute_availability
+            "compute_availability": compute_availability,
+            "tags": runtime_tags if runtime_tags else {}
         })
         GatewayUtils.handle_response(response=response, return_codes=[202])
         json_result = json.loads(response.text)
@@ -618,6 +622,7 @@ class Colony:
             "sandbox_name": sandbox_name,
             "artifacts": kwargs.get("artifacts", {}),
             "inputs": kwargs.get("inputs", {}),
+            "tags": kwargs.get("tags", {}),
             "automation": kwargs.get("automation", False),
             "compute_availability": kwargs.get("compute_availability"),
             "lazy_load_artifacts": kwargs.get("lazy_load_artifacts", False),
@@ -1328,12 +1333,13 @@ class Colony:
             self,
             provider_name: str,
             repository=None,
-            repo_relationship=None
+            repo_relationship=None,
+            repo_type="github"
     ):
         method_url = self._api_root.settings.repository_providers()
         request = {
             "name": provider_name,
-            "type": "github",
+            "type": repo_type,
         }
 
         if repository:
@@ -1600,14 +1606,15 @@ class Colony:
         GatewayUtils.handle_response(response=res, return_codes=[200])
 
     def update_custom_tag(self, old_name: str, name: str, value: str, scope: str, possible_values: [],
-                          description: str):
+                          description: str, force_remove_possible_values: bool = False):
         method_url = self._api_root.settings.custom_tag(old_name)
         request = {
             "name": name,
             "value": value,
             "scope": scope,
             "possible_values": possible_values,
-            "description": description
+            "description": description,
+            "force_remove_possible_values": force_remove_possible_values
         }
         res = self.session.put(url=method_url, json=request)
         GatewayUtils.handle_response(response=res, return_codes=[200])
