@@ -363,6 +363,7 @@ class Converters:
             display_style=blueprint_input.get("display_style"),
             optional=blueprint_input.get("optional", False),
             description=blueprint_input.get("description"),
+            possible_values=blueprint_input.get("possible_values")
         )
 
     @staticmethod
@@ -411,7 +412,8 @@ class Converters:
             launching_progress=Converters._create_launching_progress(sandbox.get('launching_progress')),
             source=Converters._create_source(sandbox.get('source')),
             direct_access=sandbox.get('direct_access', 'off'),
-            outputs=Converters._create_sandbox_outputs(sandbox.get('outputs'))
+            outputs=Converters._create_sandbox_outputs(sandbox.get('outputs')),
+            tags=Converters.create_custom_tag_response_list(sandbox.get('tags'))
         )
 
     @staticmethod
@@ -459,7 +461,8 @@ class Converters:
             debugging_service=production.get('debugging_service'),
             launching_progress=Converters._create_launching_progress(production.get('launching_progress')),
             direct_access=production.get('direct_access', 'off'),
-            outputs=Converters._create_sandbox_outputs(production['outputs'])
+            outputs=Converters._create_sandbox_outputs(production['outputs']),
+            tags=Converters.create_custom_tag_response_list(production.get('tags'))
         )
 
     @staticmethod
@@ -496,7 +499,8 @@ class Converters:
             debugging_service=production.get('debugging_service'),
             launching_progress=Converters._create_launching_progress(production.get('launching_progress')),
             direct_access=production.get('direct_access', 'off'),
-            outputs=Converters._create_sandbox_outputs(production['outputs'])
+            outputs=Converters._create_sandbox_outputs(production['outputs']),
+            tags=Converters.create_custom_tag_response_list(production.get('tags'))
         )
 
     @staticmethod
@@ -1220,6 +1224,12 @@ class Converters:
             created_date=data['created_date']
         )
 
+    @staticmethod
+    def create_custom_tag_response_list(custom_tags: Optional[List[dict]]) -> Optional[List[CustomTagResponse]]:
+        if custom_tags is None:
+            return None
+        return [Converters.create_custom_tag_response(custom_tag) for custom_tag in custom_tags]
+
     @staticmethod
     def create_custom_tag_override_response(data: dict) -> CustomTagOverrideResponse:
         return CustomTagOverrideResponse(
