@@ -29,6 +29,7 @@ class TheGateway:
                 "email": req.email,
                 "password": req.password,
                 "phone_number": req.phone_number,
+                "company_name": req.company_name
             },
         )
         GatewayUtils.handle_response(response=response, return_codes=[200])
@@ -43,6 +44,7 @@ class TheGateway:
                 "email": req.email,
                 "password": req.password,
                 "phone_number": req.phone_number,
+                "company_name": req.company_name,
                 "utm_campaign": req.utm_campaign,
             },
         )
@@ -56,6 +58,8 @@ class TheGateway:
             },
         )
         GatewayUtils.handle_response(response=response, return_codes=[200])
+        response_json = json.loads(response.text)
+        return Converters.create_create_account_finalize_response(response_json)
 
     def account_login(self, account: str, email: str, password: str) -> TokenResponse:
         response = self._session.post(
